@@ -313,8 +313,8 @@ class Block:
             if transaction.input["type"] == "token-transfer":
                 if float(transaction.input["data"]["amount"]) >= 0:
                     if self.addresses.get_balance(pve, pbc) >= float(transaction.input["data"]["amount"]):
-                        self.addresses.credit_address(transaction.input["data"]["to"], float(transaction.input["data"]["amount"]))
-                        self.addresses.credit_address(pbc, -float(transaction.input["data"]["amount"]))
+                        self.addresses.credit_wallet(transaction.input["data"]["to"], float(transaction.input["data"]["amount"]))
+                        self.addresses.credit_wallet(pbc, -float(transaction.input["data"]["amount"]))
             elif transaction.input["type"] == "contract-action":
                 # if collection name is valid continue
                 # create collection
